@@ -9,13 +9,13 @@
 ;; Maintainer: USAMI Kenta <tadsan@zonu.me>
 ;; URL: https://github.com/emacs-php/php-mode
 ;; Keywords: languages php
-;; Version: 1.25.0
+;; Version: 1.25.1
 ;; Package-Requires: ((emacs "26.1"))
 ;; License: GPL-3.0-or-later
 
 (eval-and-compile
   (make-obsolete-variable
-   (defconst php-mode-version-number "1.25.0" "PHP Mode version number.")
+   (defconst php-mode-version-number "1.25.1" "PHP Mode version number.")
    "Please call (php-mode-version :as-number t) for compatibility." "1.24.2"))
 
 ;; This program is free software; you can redistribute it and/or modify
@@ -73,6 +73,7 @@
 (require 'custom)
 (require 'speedbar)
 (require 'imenu)
+(require 'consult-imenu nil t)
 (require 'package)
 (require 'nadvice)
 (require 'mode-local)
@@ -82,6 +83,7 @@
   (require 'rx)
   (require 'cl-lib)
   (require 'flymake)
+  (require 'flymake-proc)
   (require 'php-flymake)
   (require 'regexp-opt)
   (declare-function acm-backend-tabnine-candidate-expand "ext:acm-backend-tabnine"
@@ -1267,6 +1269,16 @@ After setting the stylevars run hook `php-mode-STYLENAME-hook'."
     #'semantic-create-imenu-index)
   "Imenu index function for PHP.")
 
+(when (bound-and-true-p consult-imenu-config)
+  (add-to-list 'consult-imenu-config '(php-mode :toplevel "Namespace"
+                                                :types ((?n "Namespace" font-lock-function-name-face)
+                                                        (?p "Properties" font-lock-type-face)
+                                                        (?o "Constants" font-lock-type-face)
+                                                        (?c "Classes"    font-lock-type-face)
+                                                        (?f "Functions" font-lock-function-name-face)
+                                                        (?i "Imports" font-lock-type-face)
+                                                        (?m "Methods"  font-lock-function-name-face)))))
+
 (autoload 'php-local-manual-complete-function "php-local-manual")
 
 (defun php-complete-function ()
