@@ -5,7 +5,7 @@
 ;; Author: USAMI Kenta <tadsan@zonu.me>
 ;; Keywords: tools, files
 ;; URL: https://github.com/emacs-php/php-mode
-;; Version: 1.24.3
+;; Version: 1.25.1
 ;; License: GPL-3.0-or-later
 
 ;; This program is free software; you can redistribute it and/or modify
@@ -40,12 +40,6 @@
 ;;
 ;; Return path to PHP executable file with the project settings overriding.
 ;;
-;; ### `php-project-get-phan-executable()'
-;;
-;; Return path to Phan executable file with the project settings overriding.
-;; Phan is a static analyzer and LSP server implementation for PHP.
-;; See https://github.com/phan/phan
-;;
 ;; ## `.dir-locals.el' support
 ;;
 ;; - `php-project-coding-style'
@@ -59,10 +53,6 @@
 ;; - `php-project-php-executable'
 ;;   - Path to project specific PHP executable file.
 ;;   - If you want to use a file different from the system wide `php' command.
-;; - `php-project-phan-executable'
-;;   - Path to project specific Phan executable file.
-;;   - When not specified explicitly, it is automatically searched from
-;;     Composer's dependency of the project and `exec-path'.
 ;;
 
 ;;; Code:
@@ -142,10 +132,6 @@ defines constants, and sets the class loaders.")
   (put 'php-project-php-executable 'safe-local-variable
        #'(lambda (v) (and (stringp v) (file-executable-p v))))
 
-  (defvar-local php-project-phan-executable nil
-    "Path to phan executable file.")
-  (put 'php-project-phan-executable 'safe-local-variable #'php-project--eval-bootstrap-scripts)
-
   (defvar-local php-project-coding-style nil
     "Symbol value of the coding style of the project that PHP major mode refers to.
 
@@ -240,13 +226,6 @@ Typically it is `pear', `drupal', `wordpress', `symfony2' and `psr2'.")
    ((boundp 'php-executable) php-executable)
    (t (executable-find "php"))))
 
-(defun php-project-get-phan-executable ()
-  "Return path to phan executable file."
-  (or (car-safe (php-project--eval-bootstrap-scripts
-                 (list php-project-phan-executable
-                       (cons 'root "vendor/bin/phan"))))
-      (executable-find "phan")))
-
 (defun php-project-get-file-html-template-type (filename)
   "Return symbol T, NIL or `auto' by `FILENAME'."
   (cond
